@@ -20,3 +20,6 @@ class Status:
 
     def __ne__(self, other: object) -> bool:
         return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"Status<id={self.id}, ip={self.ip}, status={self.status}>"
