@@ -1,23 +1,21 @@
 from typing import List
+from holour.msg import Pose
 
 
 class Task:
 
-    def __init__(self, uuid: str, name: str, product_uuid: str, pose: dict, automated: bool = False,
+    def __init__(self, uuid: str, name: str, product_uuid: str, pose: Pose, automated: bool = False,
                  conditions: List[str] = None, conditions_fulfilled: bool = True, description: str = "",
                  _type: str = ''):
         conditions = conditions if conditions else []
         assert type(uuid) == str
         assert type(name) == str
         assert type(product_uuid) == str
-        assert type(pose) == dict
+        assert type(pose) == Pose
         assert type(automated) == bool
         assert type(conditions) == list, f"Type of conditions: {type(conditions)}"
         assert type(conditions_fulfilled) == bool
         assert type(description) == str
-        for key in ['x', 'y', 'z', 'rx', 'ry', 'rz']:
-            assert key in pose, f"The following must be in pose-dict: {key}. Pose: {pose}"
-            assert type(pose[key]) == float, f"{key} must be of type float instead of: {type(pose[key])}."
 
         self._type = 'task'
         self.uuid = uuid
